==> mozc_1.5.1090.102.orig.tar.gz: mozc-1.5.1090.102/unix/ibus/candidate_window_handler_interface.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_UNIX_IBUS_CANDIDATE_WINDOW_HANDLER_INTERFACE_H_
#define MOZC_UNIX_IBUS_CANDIDATE_WINDOW_HANDLER_INTERFACE_H_

#include "base/port.h"
#include "unix/ibus/ibus_header.h"

namespace mozc {
namespace commands {
class Output;
}  // namespace commands
namespace ibus {

class CandidateWindowHandlerInterface {
 public:
  CandidateWindowHandlerInterface() {}
  virtual ~CandidateWindowHandlerInterface() {}

  // Updates candidate state. This function also shows or hides candidate window
  // based on output argument.
  virtual void Update(IBusEngine *engine,
                      const commands::Output &output) ABSTRACT;

  // Hides candidate window.
  virtual void Hide(IBusEngine *engine) ABSTRACT;

  // Shows candidate window.
  virtual void Show(IBusEngine *engine) ABSTRACT;

  // Following methods handle property-changed events relevant to ibus-panel.
  // |custom_font_description| should be a string representation of
  // PangoFontDescription.
  // http://developer.gnome.org/pango/stable/pango-Fonts.html#pango-font-description-from-string
  virtual void OnIBusCustomFontDescriptionChanged(
      const string &custom_font_description) ABSTRACT;
  virtual void OnIBusUseCustomFontDescriptionChanged(
      bool use_custom_font_description) ABSTRACT;

 private:
  DISALLOW_COPY_AND_ASSIGN(CandidateWindowHandlerInterface);
};

}  // namespace ibus
}  // namespace mozc
#endif  // MOZC_UNIX_IBUS_CANDIDATE_WINDOW_HANDLER_INTERFACE_H_

==> mozc_1.15.1857.102.orig.tar.gz: mozc-1.15.1857.102/unix/ibus/candidate_window_handler_interface.h <==
// Copyright 2010-2014, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_UNIX_IBUS_CANDIDATE_WINDOW_HANDLER_INTERFACE_H_
#define MOZC_UNIX_IBUS_CANDIDATE_WINDOW_HANDLER_INTERFACE_H_

#include "base/port.h"
#include "unix/ibus/ibus_header.h"

namespace mozc {
namespace commands {
class Output;
}  // namespace commands
namespace ibus {

class CandidateWindowHandlerInterface {
 public:
  CandidateWindowHandlerInterface() {}
  virtual ~CandidateWindowHandlerInterface() {}

  // Updates candidate state. This function also shows or hides candidate window
  // based on output argument.
  virtual void Update(IBusEngine *engine,
                      const commands::Output &output) = 0;

  // Hides candidate window.
  virtual void Hide(IBusEngine *engine) = 0;

  // Shows candidate window.
  virtual void Show(IBusEngine *engine) = 0;

  // Following methods handle property-changed events relevant to ibus-panel.
  // |custom_font_description| should be a string representation of
  // PangoFontDescription.
  // http://developer.gnome.org/pango/stable/pango-Fonts.html#pango-font-description-from-string
  virtual void OnIBusCustomFontDescriptionChanged(
      const string &custom_font_description) = 0;
  virtual void OnIBusUseCustomFontDescriptionChanged(
      bool use_custom_font_description) = 0;

 private:
  DISALLOW_COPY_AND_ASSIGN(CandidateWindowHandlerInterface);
};

}  // namespace ibus
}  // namespace mozc
#endif  // MOZC_UNIX_IBUS_CANDIDATE_WINDOW_HANDLER_INTERFACE_H_
